<?php

/**
 * @file
 * This handler replaces vocabulary ids with query substitutions on several
 * places. The basic idea is to store the query substitution, and whenever
 * needed, we replace that substitution with it's real value, when validation
 * etc. needs to be done.
 */

class viewssub_handler_filter_term_node_tid extends views_handler_filter_term_node_tid {

  function extra_options_form(&$form, &$form_state) {
    if ($this->options['limit']) {
      $options = viewssub_get_substitution_options($this);

      if (empty($this->options['vid'])) {
        $this->options['vid'] = reset($options);
      }

      $form['vid'] = array(
        '#prefix' => '<div class="views-left-40">',
        '#suffix' => '</div>',
        '#type' => 'radios',
        '#title' => t('Vocabulary'),
        '#options' => $options,
        '#description' => t('Select which vocabulary to show terms for in the regular options.'),
        '#default_value' => $this->options['vid'],
      );
    }

    $form['markup_start'] = array(
      '#value' => '<div class="views-left-40">',
    );

    $form['type'] = array(
      '#type' => 'radios',
      '#title' => t('Selection type'),
      '#options' => array('select' => t('Dropdown'), 'textfield' => t('Autocomplete')),
      '#default_value' => $this->options['type'],
    );

    $form['hierarchy'] = array(
      '#type' => 'checkbox',
      '#title' => t('Show hierarchy in dropdown'),
      '#default_value' => !empty($this->options['hierarchy']),
      '#process' => array('views_process_dependency'),
      '#dependency' => array('radio:options[type]' => array('select')),
    );

    $form['markup_end'] = array(
      '#value' => '</div>',
    );
  }

  function value_form(&$form, &$form_state) {
    // Now temporarily replace our substitution with the real vid value.
    $substitution = $this->options['vid'];
    $this->options['vid'] = viewssub_get_substitution($substitution, $this);
    // Let the parent method do the heavy lifting.
    parent::value_form($form, $form_state);
    // Now take back our substitution.
    $this->options['vid'] = $substitution;
  }

  function validate_term_strings(&$form, $values) {
    // Now temporarily replace our substitution with the real vid value.
    $substitution = $this->options['vid'];
    $this->options['vid'] = viewssub_get_substitution($substitution, $this);
    // Let the parent method do the heavy lifting.
    parent::validate_term_strings(&$form, $values);
    // Now take back our substitution.
    $this->options['vid'] = $substitution;
  }
}
